# -*- coding:utf-8 -*-
"""
JAX encryption service
"""
import os.path
import sys
import os
import secrets
import string

sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
import utils.settings as st
from jax_tools.utils.encrypt import AESCipher
from jax_tools.utils.settings import JAX_KEY_FILE
from jax_tools.logger import logger


def confirm_encryption_key():
    """
    Confirm encryption key
    Returns:

    """
    if os.path.exists(JAX_KEY_FILE):
        encryption_key = open(JAX_KEY_FILE, 'r').read()
        if len(encryption_key) != 32:
            msg = 'encryption key length must be 32, please check file {} correct, or delete this file and try again.' \
                .format(JAX_KEY_FILE)
            print(msg)
            exit(1)
    else:
        # generate encryption key
        encryption_key = ''.join(secrets.choice(string.ascii_letters + string.digits) for _ in range(32))
        if os.path.exists(st.JAX_DATA_DIR) is False:
            os.mkdir(st.JAX_DATA_DIR)
        with open(JAX_KEY_FILE, 'w') as f:
            f.write(encryption_key)


# Confirm encryption key
confirm_encryption_key()

JAX_ENCRYPTION_KEY = open(st.JAX_KEY_FILE, 'r').read()
JAX_ENCRYPT = AESCipher(JAX_ENCRYPTION_KEY).encrypt
JAX_DECRYPT = AESCipher(JAX_ENCRYPTION_KEY).decrypt

if __name__ == '__main__':
    try:
        _plaintext = sys.argv[1]
        if _plaintext == '-d':
            print(JAX_DECRYPT(sys.argv[2]))
        else:
            print(JAX_ENCRYPT(_plaintext))
    except IndexError:
        logger.info('Please give a string for JAX encryption')



# -*- coding: utf-8 -*-
"""
Check if the target IP and port is open
"""
import socket
import sys
from ping3 import ping


def check_icmp_connectivity(ip):
    """
    Check if the target IP is reachable
    Args:
        ip(str): IP address or hostname

    Returns:

    """
    try:
        # Use ping3 to check if the target IP is reachable
        if ping(ip):
            return True
        else:
            return False
    except Exception as e:
        print(e)
        return False


def check_connectivity(ip, port):
    """
    检查目标IP和端口是否可以连接
    Args:
        ip: 目标IP
        port:  目标端口

    Returns:
        True if the port is open
        False if the port is closed or the connection is refused
    """
    s = None
    network_unreachable = 'Network is unreachable'
    result_dict = {
        35: 'The port is closed',
        61: 'Connection refused, firewall restrictions may be set on the target port',
        111: 'Connection refused',
        113: 'No route to host',
        101: network_unreachable,
        110: 'Connection timed out',
        10035: network_unreachable,
        10061: 'Connection refused',
        10060: 'Connection timed out',
        10051: network_unreachable,
        10065: 'No route to host',
        10064: 'Host is down',
        10013: 'Permission denied',
        10049: 'Can\'t assign requested address'
    }
    try:
        # 创建一个socket对象
        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        s.settimeout(5)  # 设置超时时间（单位：秒）
        if isinstance(port, str):
            try:
                port = int(port)
                if port < 0 or port > 65535:
                    print("The port must be between 0 and 65535")
                    sys.exit(1)
            except ValueError:
                print("The port must be a number")
                sys.exit(1)
        # 尝试连接到目标IP和端口
        result = s.connect_ex((ip, port))
        if result == 0:
            print("Connection success")
            result = True
        elif result in result_dict.keys():
            if check_icmp_connectivity(ip):
                print("Connection error: ", result_dict[result])
            else:
                print("Connection error: ", result_dict[result], "and ping not work")
            result = False
        else:
            print("Connection error：", result)
            result = False
    except socket.error as e:
        print("Connection error：", e)
        result = False
    finally:
        if s:
            s.close()
    return result


def main():
    """
    Main function
    Returns:

    """
    if len(sys.argv) == 3:
        target_ip = sys.argv[1]
        target_port = int(sys.argv[2])
        check_connectivity(target_ip, target_port)
    else:
        print("Usage: nd <TargetIP> <TargetPort>")






import time


class ColorLog:
    INFO = 'INFO'
    DEBUG = 'DEBUG'
    WARNING = 'WARNING'
    ERROR = 'ERROR'

    STYLE_NORMAL = 0
    STYLE_BOLD = 1
    STYLE_UNDERLINE = 4
    STYLE_INVERSE = 7

    COLOR_CYANIC = 36
    COLOR_RED = 31
    COLOR_GREEN = 32
    COLOR_YELLOW = 33
    COLOR_FUCHSIA = 35
    COLOR_NORMAL = 39

    @staticmethod
    def format_message(level, msg):
        timestamp = time.strftime('%H:%M:%S')
        return '\033[0;33;39m[{0}] [{1}] {2}\033[0m'.format(timestamp, level, msg)

    def info(self, msg):
        print(self.format_message(self.INFO, msg))

    def warning(self, msg):
        print(self.format_message(self.WARNING, msg))

    def error(self, msg):
        print(self.format_message(self.ERROR, msg))

    def debug(self, msg):
        print(self.format_message(self.DEBUG, msg))

    @classmethod
    def colorful_text(cls, style, color_num, msg):
        return '\033[{0};33;{1}m{2}\033[0m'.format(style, color_num, msg)


class GetColor:
    @staticmethod
    def score(s):
        if s == '':
            return ColorLog.COLOR_NORMAL
        else:
            s = float(s)
            if s > 9.0:
                return ColorLog.COLOR_FUCHSIA
            elif s > 7.0:
                return ColorLog.COLOR_RED
            elif s > 4.0:
                return ColorLog.COLOR_YELLOW
            elif s > 0:
                return ColorLog.COLOR_GREEN
            else:
                return ColorLog.COLOR_NORMAL

    @staticmethod
    def date(d):
        if not d.count('-'):
            return ColorLog.COLOR_NORMAL
        year = int(d.split('-')[0])
        now_year = int(time.strftime('%Y'))
        if year >= now_year:
            return


if __name__ == '__main__':
    ColorLog.info('info')
    ColorLog.warning('warning')